# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tyrannosaurus']

package_data = \
{'': ['*'], 'tyrannosaurus': ['resources/*']}

install_requires = \
['grayskull>=0.8.4,<1', 'requests>=2.24,<3', 'tomlkit>=0.7,<1', 'typer>=0.3,<1']

entry_points = \
{'console_scripts': ['tyrannosaurus = tyrannosaurus.cli:cli']}

setup_kwargs = {
    'name': 'tyrannosaurus',
    'version': '0.8.1',
    'description': 'Opinionated Python template and metadata synchronizer for 2021.',
    'long_description': '# Tyrannosaurus Reqs\n[![Version status](https://img.shields.io/pypi/status/tyrannosaurus)](https://pypi.org/project/tyrannosaurus/)\n[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)\n[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/tyrannosaurus)](https://pypi.org/project/tyrannosaurus/)\n[![Docker](https://img.shields.io/docker/v/dmyersturnbull/tyrannosaurus?color=green&label=DockerHub)](https://hub.docker.com/repository/docker/dmyersturnbull/tyrannosaurus)\n[![GitHub release (latest SemVer including pre-releases)](https://img.shields.io/github/v/release/dmyersturnbull/tyrannosaurus?include_prereleases&label=GitHub)](https://github.com/dmyersturnbull/tyrannosaurus/releases)\n[![Latest version on PyPi](https://badge.fury.io/py/tyrannosaurus.svg)](https://pypi.org/project/tyrannosaurus/)\n[![Documentation status](https://readthedocs.org/projects/tyrannosaurus/badge/?version=latest&style=flat-square)](https://tyrannosaurus.readthedocs.io/en/stable/)\n[![Build & test](https://github.com/dmyersturnbull/tyrannosaurus/workflows/Build%20&%20test/badge.svg)](https://github.com/dmyersturnbull/tyrannosaurus/actions)\n[![Travis](https://img.shields.io/travis/dmyersturnbull/tyrannosaurus?label=Travis)](https://travis-ci.org/dmyersturnbull/tyrannosaurus)\n[![Maintainability](https://api.codeclimate.com/v1/badges/5e3b38c9b9c418461dc3/maintainability)](https://codeclimate.com/github/dmyersturnbull/tyrannosaurus/maintainability)\n[![Coverage](https://coveralls.io/repos/github/dmyersturnbull/tyrannosaurus/badge.svg?branch=master&service=github)](https://coveralls.io/github/dmyersturnbull/tyrannosaurus?branch=master)\n\nAn opinionated, forwards-looking Python template for 2021.\n\nThis is a massively upgraded, trimmed-down, modern alternative to\n[cookiecutter](https://github.com/cookiecutter/cookiecutter) built with [Poetry](https://python-poetry.org/),\n[Tox](https://github.com/tox-dev/tox), and [Github Actions](https://github.com/features/actions).\nNo setup.py, requirements.txt, or eggs. If you’re curious why that infrastructure is problematic,\nsee [this post](https://dmyersturnbull.github.io/#-the-python-build-landscape)\n\nI wrote this after making nearly 50 commits to configure\nreadthedocs, PyPi, Poetry, Tox, Docker, Travis, and Github actions.\nThis avoids that struggle for 99% of projects.\nIt’s technically in an alpha state, but it’s pretty solid.\n\n\n#### Basic usage:\n\nTo generate a new project, run:\n\n```bash\npip install tyrannosaurus\ntyrannosaurus new projectname --user gituserororg --track\n```\n\nIt’ll give you a link with some steps to follow (such as adding API keys).\nOf course, you can modify the generated files however you see fit.\n\n\n#### Main behavior / features:\n\nHere’s how your new project will behave, by default:\n\n- When you _commit_, your code is linted and files are checked.\n- When you _push or make a pull request_, your code is tested,\n  security checks are run, and artifacts are built.\n- When you _push_ to main, badges are updated and documentation is sent\n- When you _release on Github_, your code is published to PyPi and DockerHub,\n  and artifacts are attached to the Github release\n  (Add `PYPI_TOKEN` and `COVERALLS_REPO_TOKEN` as Github repo secrets.)\n- If you run `tyrannosaurus sync`, your project metadata is synchronized to pyproject.toml\n\nTox, Git Pre-Commit, and Github Actions provide these behaviors.\nYou can modify them via `pyproject.toml`, `tox.ini`, `pre-commit-config.yml` and `.github/workflows`.\n\n#### Extras / nice-to-haves:\n\nYou’ll also have nice Github labels, templates for issues and pull requests, and a changelog template.\nThese can be modified by editing `.github/labels.json`, `.github/ISSUE_TEMPLATE`, and `CHANGELOG.md`.\nIntegration is also provided for Travis, Azure, Anaconda/Conda, and a few other tools.\n\n\n**[See the docs 📚](https://tyrannosaurus.readthedocs.io/en/stable/)** for more information.\n\n\n#### Full features / integrations:\n\n  - Packaging and dependency management with [Poetry](https://python-poetry.org/)\n  - Python 3.8, 3.9, and 3.8 (3.6 and 3.7 with a small change)\n  - Only modern files: *no* manifest file, setup.py, requirements.txt, setup.cfg, or eggs\n  - Continuous integration with [Github Actions](https://github.com/features/actions),\n    [Travis](https://www.travis-ci.com/), or [Azure Pipelines](https://azure.microsoft.com/en-us/services/devops/pipelines/) †\n  - Continuous deployment to [PyPi](http://pypi.org/) and [Dockerhub](https://hub.docker.com/)\n  - Automatic attachment of [sdits](https://docs.python.org/3/distutils/sourcedist.html)\n    and [wheels](https://pythonwheels.com/) to [Github Releases](https://docs.github.com/en/free-pro-team@latest/github/administering-a-repository/about-releases)\n  - Documentation sent to [readthedocs](https://readthedocs.org/)\n  - Nice documentation defaults with [Sphinx extensions](https://www.sphinx-doc.org/en/master/usage/extensions/index.html)\n  - Test automation with [Tox](https://tox.readthedocs.io)\n  - Code quality and coverage [badges](https://github.com/badges/shields) with [Coveralls](https://coveralls.io/),\n    [codecov](https://about.codecov.io/), and [CodeClimate](https://codeclimate.com/)\n    that reflect the main branch\n  - Code linting with [pre-commit](https://pre-commit.com/), [Black](https://pypi.org/project/black/),\n    and [Prettifier](https://prettier.io/)\n  - Security analysis with [Bandit](https://github.com/PyCQA/bandit),\n    [CodeQL](https://docs.github.com/en/free-pro-team@latest/github/finding-security-vulnerabilities-and-errors-in-your-code/),\n    and [safety](https://github.com/pyupio/safety) ([issue](https://github.com/pyupio/safety/issues/201))\n  - Static type analysis with [mypy](https://mypy.readthedocs.io)\n  - Auto-generation and synchronization of [Conda-Forge](https://conda-forge.org/) recipes and environment YML files\n  - IDE hints via [EditorConfig](https://editorconfig.org/) with good defaults for most languages\n  - Nice gitignore, dockerignore; issue labels; and Github-recognized issue templates, pull request templates,\n    [ChangeLog](https://keepachangelog.com), readme, license, and contributing guide\n  - [CodeMeta](https://codemeta.github.io/user-guide/) and [CITATION.cff](https://citation-file-format.github.io/)\n  - Dependency updating with [Dependabot](https://dependabot.com/) (disabled by default)\n  - Synchronization of project metadata with [Tyrannosaurus](https://tyrannosaurus.readthedocs.io/),\n    so that only pyproject.toml needs to be updated\n\n\n† The Azure workflow currently only builds the Docker image.\n\n\n#### Syncing to pyproject.toml:\n\n*Note: This feature is only partly complete.*\n\nTyrannosaurus has an optional `sync` command that synchronizes metadata from `pyproject.toml` to other files,\nso that **all of your metadata is in pyproject.toml**.\nThere are 16 available target files, including `docs/conf.py`, `tox.ini`, `.pre-commit-config.yaml`, `readthedocs.yml`,\n`.travis.yml`, and `__init__.py`.\nSettings like dev dependencies, project version, license headers, and preferred line length can be listed exactly once,\nin pyproject.toml.\n\nTyrannosaurus itself can be included as a dependency (but is not by default).\nRunning `tyrannosaurus build` will run poetry lock, synchronize project metadata (via `sync`), build, run tests,\ninstall, and clean up.\nTarget files can be disabled in `[tool.tyrannosaurus.targets]`.\n\n\n#### Building your project locally:\n\nTo run locally, install [Poetry](https://github.com/python-poetry/poetry)\nand [Tox](https://tox.readthedocs.io/en/latest/) (`pip install tox`).\nThen just type `tox` to build artifacts and run tests.\nTo create an initial Anaconda recipe or environment file, run `tyrannosaurus recipe` or `tyrannosaurus env`.\n\n\n#### Similar tools:\n\n- [hypermodern-python](https://github.com/cjolowicz/hypermodern-python), a Python template that is similarly modern.\n  It looks solid but has fewer integrations.\n  A few choices were different, such as the use of [Nox](https://github.com/theacodes/nox).\n  As of 2020-12, the last update was in 2020-04.\n- [cookiecutter-hypermodern-python](https://github.com/cjolowicz/cookiecutter-hypermodern-python)\n- [cookiecutter](https://github.com/cookiecutter/cookiecutter), which still uses setup.py\n- [python-blueprint](https://github.com/johnthagen/python-blueprint), which is useful to look through\n  but still uses setup.py\n\n\n#### Contributing:\n\n[New issues](https://github.com/dmyersturnbull/tyrannosaurus/issues) and pull requests are welcome.\nPlease refer to the [contributing guide](https://github.com/dmyersturnbull/tyrannosaurus/blob/master/CONTRIBUTING.md).\nGenerated with tyrannosaurus: `tyrannosaurus new tyrannosaurus`\n\n\n```text\n                                              .++++++++++++.\n                                           .++HHHHHHH^^HHH+.\n                                          .HHHHHHHHHH++-+-++.\n                                         .HHHHHHHHHHH:t~~~~~\n                                        .+HHHHHHHHHHjjjjjjjj.\n                                       .+NNNNNNNNN/++/:--..\n                              ........+NNNNNNNNNN.\n                          .++++BBBBBBBBBBBBBBB.\n .tttttttt:..           .++BBBBBBBBBBBBBBBBBBB.\n+tt+.      ``         .+BBBBBBBBBBBBBBBBBBBBB+++cccc.\nttt.               .-++BBBBBBBBBBBBBBBBBBBBBB++.ccc.\n+ttt++++:::::++++++BBBBBBBBBBBBBBBBBBBBBBB+..++.\n.+TTTTTTTTTTTTTBBBBBBBBBBBBBBBBBBBBBBBBB+.    .ccc.\n  .++TTTTTTTTTTBBBBBBBBBBBBBBBBBBBBBBBB+.      .cc.\n    ..:++++++++++++++++++BBBBBB++++BBBB.\n           .......      -LLLLL+. -LLLLL.\n                        -LLLL+.   -LLLL+.\n                        +LLL+       +LLL+\n                        +LL+         +ff+\n                        +ff++         +++:\n                        ++++:\n```\n',
    'author': 'Douglas Myers-Turnbull',
    'author_email': None,
    'maintainer': 'Douglas Myers-Turnbull',
    'maintainer_email': None,
    'url': 'https://github.com/dmyersturnbull/tyrannosaurus',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4',
}


setup(**setup_kwargs)
